@@ -7,12 +7,14 @@ pub mod battery;
 pub mod buf;
 pub mod bun;
 pub mod c;
+pub mod cc;
 pub mod character;
 pub mod cmake;
 pub mod cmd_duration;
 pub mod cobol;
 pub mod conda;
 pub mod container;
+pub mod cpp;
 pub mod crystal;
 pub mod custom;
 pub mod daml;
@@ -36,6 +38,7 @@ pub mod git_commit;
 pub mod git_metrics;
 pub mod git_state;
 pub mod git_status;
+pub mod gleam;
 pub mod go;
 pub mod gradle;
 pub mod guix_shell;
@@ -54,10 +57,15 @@ pub mod localip;
 pub mod lua;
 pub mod memory_usage;
 pub mod meson;
+pub mod mise;
+pub mod mojo;
+pub mod nats;
+pub mod netns;
 pub mod nim;
 pub mod nix_shell;
 pub mod nodejs;
 pub mod ocaml;
+pub mod odin;
 pub mod opa;
 pub mod openstack;
 pub mod os;
@@ -65,9 +73,11 @@ pub mod package;
 pub mod perl;
 pub mod php;
 pub mod pijul_channel;
+pub mod pixi;
 pub mod pulumi;
 pub mod purescript;
 pub mod python;
+pub mod quarto;
 pub mod raku;
 pub mod red;
 pub mod rlang;
@@ -134,6 +144,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     container: container::ContainerConfig<'a>,
     #[serde(borrow)]
+    cpp: cpp::CppConfig<'a>,
+    #[serde(borrow)]
     crystal: crystal::CrystalConfig<'a>,
     #[serde(borrow)]
     daml: daml::DamlConfig<'a>,
@@ -178,6 +190,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     git_status: git_status::GitStatusConfig<'a>,
     #[serde(borrow)]
+    gleam: gleam::GleamConfig<'a>,
+    #[serde(borrow)]
     golang: go::GoConfig<'a>,
     #[serde(borrow)]
     gradle: gradle::GradleConfig<'a>,
@@ -213,6 +227,14 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     meson: meson::MesonConfig<'a>,
     #[serde(borrow)]
+    mise: mise::MiseConfig<'a>,
+    #[serde(borrow)]
+    mojo: mojo::MojoConfig<'a>,
+    #[serde(borrow)]
+    nats: nats::NatsConfig<'a>,
+    #[serde(borrow)]
+    netns: netns::NetnsConfig<'a>,
+    #[serde(borrow)]
     nim: nim::NimConfig<'a>,
     #[serde(borrow)]
     nix_shell: nix_shell::NixShellConfig<'a>,
@@ -221,6 +243,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     ocaml: ocaml::OCamlConfig<'a>,
     #[serde(borrow)]
+    odin: odin::OdinConfig<'a>,
+    #[serde(borrow)]
     opa: opa::OpaConfig<'a>,
     #[serde(borrow)]
     openstack: openstack::OspConfig<'a>,
@@ -235,12 +259,16 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     pijul_channel: pijul_channel::PijulConfig<'a>,
     #[serde(borrow)]
+    pixi: pixi::PixiConfig<'a>,
+    #[serde(borrow)]
     pulumi: pulumi::PulumiConfig<'a>,
     #[serde(borrow)]
     purescript: purescript::PureScriptConfig<'a>,
     #[serde(borrow)]
     python: python::PythonConfig<'a>,
     #[serde(borrow)]
+    quarto: quarto::QuartoConfig<'a>,
+    #[serde(borrow)]
     raku: raku::RakuConfig<'a>,
     #[serde(borrow)]
     red: red::RedConfig<'a>,
