@@ -1,4 +1,4 @@
-use indexmap::{indexmap, IndexMap};
+use indexmap::{IndexMap, indexmap};
 use os_info::Type;
 use serde::{Deserialize, Serialize};
 
@@ -22,7 +22,7 @@ impl<'a> OSConfig<'a> {
     }
 }
 
-impl<'a> Default for OSConfig<'a> {
+impl Default for OSConfig<'_> {
     fn default() -> Self {
         OSConfig {
             format: "[$symbol]($style)",
@@ -36,6 +36,8 @@ impl<'a> Default for OSConfig<'a> {
                 Type::Android => "🤖 ",
                 Type::Arch => "🎗️ ",
                 Type::Artix => "🎗️ ",
+                Type::Bluefin => "🐟 ",
+                Type::CachyOS => "🎗️ ",
                 Type::CentOS => "💠 ",
                 Type::Debian => "🌀 ",
                 Type::DragonFly => "🐉 ",
@@ -57,6 +59,7 @@ impl<'a> Default for OSConfig<'a> {
                 Type::Mint => "🌿 ",
                 Type::NetBSD => "🚩 ",
                 Type::NixOS => "❄️ ",
+                Type::Nobara =>  "🎩 ",
                 Type::OpenBSD => "🐡 ",
                 Type::OpenCloudOS => "☁️ ",
                 Type::openEuler => "🦉 ",
@@ -73,6 +76,7 @@ impl<'a> Default for OSConfig<'a> {
                 Type::Ubuntu => "🎯 ",
                 Type::Ultramarine => "🔷 ",
                 Type::Unknown => "❓ ",
+                Type::Uos => "🐲 ",
                 Type::Void => "  ",
                 Type::Windows => "🪟 ",
                 // Future symbols.
