@@ -18,6 +18,7 @@ pub struct StarshipRootConfig {
     pub scan_timeout: u64,
     pub command_timeout: u64,
     pub add_newline: bool,
+    pub follow_symlinks: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub palette: Option<String>,
     pub palettes: HashMap<String, Palette>,
@@ -36,9 +37,11 @@ pub const PROMPT_ORDER: &[&str] = &[
     "shlvl",
     "singularity",
     "kubernetes",
+    "nats",
     "directory",
     "vcsh",
     "fossil_branch",
+    "fossil_metrics",
     "git_branch",
     "git_commit",
     "git_state",
@@ -54,6 +57,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "c",
     "cmake",
     "cobol",
+    "cpp",
     "daml",
     "dart",
     "deno",
@@ -62,6 +66,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "elm",
     "erlang",
     "fennel",
+    "gleam",
     "golang",
     "gradle",
     "haskell",
@@ -71,15 +76,18 @@ pub const PROMPT_ORDER: &[&str] = &[
     "julia",
     "kotlin",
     "lua",
+    "mojo",
     "nim",
     "nodejs",
     "ocaml",
+    "odin",
     "opa",
     "perl",
     "php",
     "pulumi",
     "purescript",
     "python",
+    "quarto",
     "raku",
     "rlang",
     "red",
@@ -89,6 +97,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "solidity",
     "swift",
     "terraform",
+    "typst",
     "vlang",
     "vagrant",
     "zig",
@@ -97,6 +106,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "guix_shell",
     "nix_shell",
     "conda",
+    "pixi",
     "meson",
     "spack",
     "memory_usage",
@@ -104,7 +114,9 @@ pub const PROMPT_ORDER: &[&str] = &[
     "gcloud",
     "openstack",
     "azure",
+    "direnv",
     "env_var",
+    "mise",
     "crystal",
     "custom",
     "sudo",
@@ -116,6 +128,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "time",
     "status",
     "container",
+    "netns",
     "os",
     "shell",
     "character",
@@ -133,6 +146,7 @@ impl Default for StarshipRootConfig {
             scan_timeout: 30,
             command_timeout: 500,
             add_newline: true,
+            follow_symlinks: true,
             palette: None,
             palettes: HashMap::default(),
         }
