@@ -18,7 +18,7 @@ pub struct SwiftConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for SwiftConfig<'a> {
+impl Default for SwiftConfig<'_> {
     fn default() -> Self {
         SwiftConfig {
             format: "via [$symbol($version )]($style)",
