@@ -18,7 +18,7 @@ pub struct TimeConfig<'a> {
     pub time_range: &'a str,
 }
 
-impl<'a> Default for TimeConfig<'a> {
+impl Default for TimeConfig<'_> {
     fn default() -> Self {
         TimeConfig {
             format: "at [$time]($style) ",
