@@ -2,17 +2,17 @@ use crate::config::{ModuleConfig, StarshipConfig};
 use crate::configs::StarshipRootConfig;
 use crate::context_env::Env;
 use crate::module::Module;
-use crate::utils::{create_command, exec_timeout, read_file, CommandOutput, PathExt};
+use crate::utils::{CommandOutput, PathExt, create_command, exec_timeout, read_file};
 
 use crate::modules;
 use crate::utils;
 use clap::Parser;
 use gix::{
+    Repository, ThreadSafeRepository,
     repository::Kind,
     sec::{self as git_sec, trust::DefaultForLevel},
-    state as git_state, Repository, ThreadSafeRepository,
+    state as git_state,
 };
-use once_cell::sync::OnceCell;
 #[cfg(test)]
 use std::collections::HashMap;
 use std::collections::HashSet;
@@ -25,6 +25,7 @@ use std::num::ParseIntError;
 use std::path::{Path, PathBuf};
 use std::str::FromStr;
 use std::string::String;
+use std::sync::OnceLock;
 use std::time::{Duration, Instant};
 use terminal_size::terminal_size;
 
@@ -44,13 +45,13 @@ pub struct Context<'a> {
     pub logical_dir: PathBuf,
 
     /// A struct containing directory contents in a lookup-optimized format.
-    dir_contents: OnceCell<DirContents>,
+    dir_contents: OnceLock<Result<DirContents, std::io::Error>>,
 
     /// Properties to provide to modules.
     pub properties: Properties,
 
     /// Private field to store Git information for modules who need it
-    repo: OnceCell<Repo>,
+    repo: OnceLock<Result<Repo, Box<gix::discover::Error>>>,
 
     /// The shell the user is assumed to be running
     pub shell: Shell,
@@ -134,7 +135,7 @@ impl<'a> Context<'a> {
         if properties
             .pipestatus
             .as_deref()
-            .map_or(false, |p| p.len() == 1 && p[0].is_empty())
+            .is_some_and(|p| p.len() == 1 && p[0].is_empty())
         {
             properties.pipestatus = None;
         }
@@ -166,8 +167,8 @@ impl<'a> Context<'a> {
             properties,
             current_dir,
             logical_dir,
-            dir_contents: OnceCell::new(),
-            repo: OnceCell::new(),
+            dir_contents: OnceLock::new(),
+            repo: OnceLock::new(),
             shell,
             target,
             width,
@@ -286,19 +287,20 @@ impl<'a> Context<'a> {
     }
 
     /// Will lazily get repo root and branch when a module requests it.
-    pub fn get_repo(&self) -> Result<&Repo, Box<gix::discover::Error>> {
+    pub fn get_repo(&self) -> Result<&Repo, &gix::discover::Error> {
         self.repo
-            .get_or_try_init(|| -> Result<Repo, Box<gix::discover::Error>> {
+            .get_or_init(|| -> Result<Repo, Box<gix::discover::Error>> {
                 // custom open options
                 let mut git_open_opts_map =
                     git_sec::trust::Mapping::<gix::open::Options>::default();
 
-                // don't use the global git configs
+                // Load all the configuration as it affects aspects of the
+                // `git_status` and `git_metrics` modules.
                 let config = gix::open::permissions::Config {
-                    git_binary: false,
-                    system: false,
-                    git: false,
-                    user: false,
+                    git_binary: true,
+                    system: true,
+                    git: true,
+                    user: true,
                     env: true,
                     includes: true,
                 };
@@ -345,13 +347,13 @@ impl<'a> Context<'a> {
 
                 let fs_monitor_value_is_true = repository
                     .config_snapshot()
-                    .boolean("core.fs_monitor")
+                    .boolean("core.fsmonitor")
                     .unwrap_or(false);
 
                 Ok(Repo {
                     repo: shared_repo,
                     branch: branch.map(|b| b.shorten().to_string()),
-                    workdir: repository.work_dir().map(PathBuf::from),
+                    workdir: repository.workdir().map(PathBuf::from),
                     path,
                     state: repository.state(),
                     remote,
@@ -359,17 +361,21 @@ impl<'a> Context<'a> {
                     kind: repository.kind(),
                 })
             })
+            .as_ref()
+            .map_err(std::convert::AsRef::as_ref)
     }
 
-    pub fn dir_contents(&self) -> Result<&DirContents, std::io::Error> {
-        self.dir_contents.get_or_try_init(|| {
-            let timeout = self.root_config.scan_timeout;
-            DirContents::from_path_with_timeout(
-                &self.current_dir,
-                Duration::from_millis(timeout),
-                self.root_config.follow_symlinks,
-            )
-        })
+    pub fn dir_contents(&self) -> Result<&DirContents, &std::io::Error> {
+        self.dir_contents
+            .get_or_init(|| {
+                let timeout = self.root_config.scan_timeout;
+                DirContents::from_path_with_timeout(
+                    &self.current_dir,
+                    Duration::from_millis(timeout),
+                    self.root_config.follow_symlinks,
+                )
+            })
+            .as_ref()
     }
 
     fn get_shell() -> Shell {
@@ -647,7 +653,7 @@ pub struct Repo {
 
     /// Contains `true` if the value of `core.fsmonitor` is set to `true`.
     /// If not `true`, `fsmonitor` is explicitly disabled in git commands.
-    fs_monitor_value_is_true: bool,
+    pub(crate) fs_monitor_value_is_true: bool,
 
     // Kind of repository, work tree or bare
     pub kind: Kind,
@@ -666,7 +672,7 @@ impl Repo {
     pub fn exec_git<T: AsRef<OsStr> + Debug>(
         &self,
         context: &Context,
-        git_args: &[T],
+        git_args: impl IntoIterator<Item = T>,
     ) -> Option<CommandOutput> {
         let mut command = create_command("git").ok()?;
 
@@ -776,19 +782,53 @@ impl<'a> ScanAncestors<'a> {
     /// files or folders is found.
     ///
     /// The scan does not cross device boundaries.
-    pub fn scan(&self) -> Option<&'a Path> {
-        let initial_device_id = self.path.device_id();
-        for dir in self.path.ancestors() {
-            if initial_device_id != dir.device_id() {
+    pub fn scan(&self) -> Option<PathBuf> {
+        let path = self.path;
+        let initial_device_id = path.device_id();
+
+        // We want to avoid reallocations during the search so we pre-allocate a buffer with enough
+        // capacity to hold the longest path + any marker (we could find the length of the longest
+        // marker programmatically but that would actually cost more than preallocating a few bytes too many).
+        let mut buf = PathBuf::with_capacity(path.as_os_str().len() + 15);
+        path.clone_into(&mut buf);
+
+        loop {
+            if initial_device_id != buf.device_id() {
                 break;
             }
 
-            if self.files.iter().any(|name| dir.join(name).is_file())
-                || self.folders.iter().any(|name| dir.join(name).is_dir())
-            {
-                return Some(dir);
+            for file in self.files {
+                // Then for each file, we look for `buf/file`
+                buf.push(file);
+
+                if buf.is_file() {
+                    buf.pop();
+                    return Some(buf);
+                }
+
+                // Removing the last pushed item means removing `file`, to replace it with either
+                // the next `file` or the first `folder`, if any
+                buf.pop();
+            }
+
+            for folder in self.folders {
+                // Then for each folder, we look for `buf/folder`
+                buf.push(folder);
+
+                if buf.is_dir() {
+                    buf.pop();
+                    return Some(buf);
+                }
+
+                buf.pop();
+            }
+
+            // Then we go up one level until there is no more level to go up with
+            if !buf.pop() {
+                break;
             }
         }
+
         None
     }
 }
@@ -864,8 +904,11 @@ pub struct Properties {
     #[clap(short = 'k', long, default_value = "viins")]
     pub keymap: String,
     /// The number of currently running jobs
-    #[clap(short, long, default_value_t, value_parser=parse_jobs)]
+    #[clap(short, long, default_value_t, value_parser=parse_i64)]
     pub jobs: i64,
+    /// The current value of SHLVL, for shells that mis-handle it in $()
+    #[clap(long, value_parser=parse_i64)]
+    pub shlvl: Option<i64>,
 }
 
 impl Default for Properties {
@@ -879,6 +922,7 @@ impl Default for Properties {
             cmd_duration: None,
             keymap: "viins".to_string(),
             jobs: 0,
+            shlvl: None,
         }
     }
 }
@@ -892,8 +936,8 @@ fn parse_trim<F: FromStr>(value: &str) -> Option<Result<F, F::Err>> {
     Some(F::from_str(value))
 }
 
-fn parse_jobs(jobs: &str) -> Result<i64, ParseIntError> {
-    parse_trim(jobs).unwrap_or(Ok(0))
+fn parse_i64(value: &str) -> Result<i64, ParseIntError> {
+    parse_trim(value).unwrap_or(Ok(0))
 }
 
 fn default_width() -> usize {
@@ -937,39 +981,47 @@ mod tests {
 
         let dc_following_symlinks = DirContents::from_path(d.path(), true)?;
 
-        assert!(ScanDir {
-            dir_contents: &dc_following_symlinks,
-            files: &["link_to_file"],
-            extensions: &[],
-            folders: &[],
-        }
-        .is_match());
+        assert!(
+            ScanDir {
+                dir_contents: &dc_following_symlinks,
+                files: &["link_to_file"],
+                extensions: &[],
+                folders: &[],
+            }
+            .is_match()
+        );
 
-        assert!(ScanDir {
-            dir_contents: &dc_following_symlinks,
-            files: &[],
-            extensions: &[],
-            folders: &["link_to_folder"],
-        }
-        .is_match());
+        assert!(
+            ScanDir {
+                dir_contents: &dc_following_symlinks,
+                files: &[],
+                extensions: &[],
+                folders: &["link_to_folder"],
+            }
+            .is_match()
+        );
 
         let dc_not_following_symlinks = DirContents::from_path(d.path(), false)?;
 
-        assert!(ScanDir {
-            dir_contents: &dc_not_following_symlinks,
-            files: &["link_to_file"],
-            extensions: &[],
-            folders: &[],
-        }
-        .is_match());
+        assert!(
+            ScanDir {
+                dir_contents: &dc_not_following_symlinks,
+                files: &["link_to_file"],
+                extensions: &[],
+                folders: &[],
+            }
+            .is_match()
+        );
 
-        assert!(!ScanDir {
-            dir_contents: &dc_not_following_symlinks,
-            files: &[],
-            extensions: &[],
-            folders: &["link_to_folder"],
-        }
-        .is_match());
+        assert!(
+            !ScanDir {
+                dir_contents: &dc_not_following_symlinks,
+                files: &[],
+                extensions: &[],
+                folders: &["link_to_folder"],
+            }
+            .is_match()
+        );
 
         Ok(())
     }
@@ -980,91 +1032,107 @@ mod tests {
         let follow_symlinks = true;
         let empty_dc = DirContents::from_path(empty.path(), follow_symlinks)?;
 
-        assert!(!ScanDir {
-            dir_contents: &empty_dc,
-            files: &["package.json"],
-            extensions: &["js"],
-            folders: &["node_modules"],
-        }
-        .is_match());
+        assert!(
+            !ScanDir {
+                dir_contents: &empty_dc,
+                files: &["package.json"],
+                extensions: &["js"],
+                folders: &["node_modules"],
+            }
+            .is_match()
+        );
         empty.close()?;
 
         let rust = testdir(&["README.md", "Cargo.toml", "src/main.rs"])?;
         let rust_dc = DirContents::from_path(rust.path(), follow_symlinks)?;
-        assert!(!ScanDir {
-            dir_contents: &rust_dc,
-            files: &["package.json"],
-            extensions: &["js"],
-            folders: &["node_modules"],
-        }
-        .is_match());
+        assert!(
+            !ScanDir {
+                dir_contents: &rust_dc,
+                files: &["package.json"],
+                extensions: &["js"],
+                folders: &["node_modules"],
+            }
+            .is_match()
+        );
         rust.close()?;
 
         let java = testdir(&["README.md", "src/com/test/Main.java", "pom.xml"])?;
         let java_dc = DirContents::from_path(java.path(), follow_symlinks)?;
-        assert!(!ScanDir {
-            dir_contents: &java_dc,
-            files: &["package.json"],
-            extensions: &["js"],
-            folders: &["node_modules"],
-        }
-        .is_match());
+        assert!(
+            !ScanDir {
+                dir_contents: &java_dc,
+                files: &["package.json"],
+                extensions: &["js"],
+                folders: &["node_modules"],
+            }
+            .is_match()
+        );
         java.close()?;
 
         let node = testdir(&["README.md", "node_modules/lodash/main.js", "package.json"])?;
         let node_dc = DirContents::from_path(node.path(), follow_symlinks)?;
-        assert!(ScanDir {
-            dir_contents: &node_dc,
-            files: &["package.json"],
-            extensions: &["js"],
-            folders: &["node_modules"],
-        }
-        .is_match());
+        assert!(
+            ScanDir {
+                dir_contents: &node_dc,
+                files: &["package.json"],
+                extensions: &["js"],
+                folders: &["node_modules"],
+            }
+            .is_match()
+        );
         node.close()?;
 
         let tarballs = testdir(&["foo.tgz", "foo.tar.gz"])?;
         let tarballs_dc = DirContents::from_path(tarballs.path(), follow_symlinks)?;
-        assert!(ScanDir {
-            dir_contents: &tarballs_dc,
-            files: &[],
-            extensions: &["tar.gz"],
-            folders: &[],
-        }
-        .is_match());
+        assert!(
+            ScanDir {
+                dir_contents: &tarballs_dc,
+                files: &[],
+                extensions: &["tar.gz"],
+                folders: &[],
+            }
+            .is_match()
+        );
         tarballs.close()?;
 
         let dont_match_ext = testdir(&["foo.js", "foo.ts"])?;
         let dont_match_ext_dc = DirContents::from_path(dont_match_ext.path(), follow_symlinks)?;
-        assert!(!ScanDir {
-            dir_contents: &dont_match_ext_dc,
-            files: &[],
-            extensions: &["js", "!notfound", "!ts"],
-            folders: &[],
-        }
-        .is_match());
+        assert!(
+            !ScanDir {
+                dir_contents: &dont_match_ext_dc,
+                files: &[],
+                extensions: &["js", "!notfound", "!ts"],
+                folders: &[],
+            }
+            .is_match()
+        );
         dont_match_ext.close()?;
 
         let dont_match_file = testdir(&["goodfile", "evilfile"])?;
         let dont_match_file_dc = DirContents::from_path(dont_match_file.path(), follow_symlinks)?;
-        assert!(!ScanDir {
-            dir_contents: &dont_match_file_dc,
-            files: &["goodfile", "!notfound", "!evilfile"],
-            extensions: &[],
-            folders: &[],
-        }
-        .is_match());
+        assert!(
+            !ScanDir {
+                dir_contents: &dont_match_file_dc,
+                files: &["goodfile", "!notfound", "!evilfile"],
+                extensions: &[],
+                folders: &[],
+            }
+            .is_match()
+        );
         dont_match_file.close()?;
 
         let dont_match_folder = testdir(&["gooddir/somefile", "evildir/somefile"])?;
         let dont_match_folder_dc =
             DirContents::from_path(dont_match_folder.path(), follow_symlinks)?;
-        assert!(!ScanDir {
-            dir_contents: &dont_match_folder_dc,
-            files: &[],
-            extensions: &[],
-            folders: &["gooddir", "!notfound", "!evildir"],
-        }
-        .is_match());
+        assert!(
+            !ScanDir {
+                dir_contents: &dont_match_folder_dc,
+                files: &[],
+                extensions: &[],
+                folders: &["gooddir", "!notfound", "!evildir"],
+            }
+            .is_match()
+        );
         dont_match_folder.close()?;
 
         Ok(())
