@@ -3,12 +3,10 @@
 use clap::crate_authors;
 use std::io;
 use std::path::PathBuf;
-use std::thread::available_parallelism;
 use std::time::SystemTime;
 
-use clap::{CommandFactory, Parser, Subcommand};
-use clap_complete::{generate, Shell as CompletionShell};
-use rand::distributions::Alphanumeric;
+use clap::{CommandFactory, Parser, Subcommand, ValueEnum};
+use clap_complete::generate;
 use rand::Rng;
 use starship::context::{Context, Properties, Target};
 use starship::module::ALL_MODULES;
@@ -28,6 +26,36 @@ struct Cli {
     command: Commands,
 }
 
+#[derive(clap::Parser, ValueEnum, Debug, Clone, PartialEq, Eq)]
+enum CompletionShell {
+    Bash,
+    Elvish,
+    Fish,
+    Nushell,
+    PowerShell,
+    Zsh,
+}
+
+fn generate_shell(shell: impl clap_complete::Generator) {
+    generate(
+        shell,
+        &mut Cli::command(),
+        "starship",
+        &mut io::stdout().lock(),
+    )
+}
+
+fn generate_completions(shell: CompletionShell) {
+    match shell {
+        CompletionShell::Bash => generate_shell(clap_complete::Shell::Bash),
+        CompletionShell::Elvish => generate_shell(clap_complete::Shell::Elvish),
+        CompletionShell::Fish => generate_shell(clap_complete::Shell::Fish),
+        CompletionShell::PowerShell => generate_shell(clap_complete::Shell::PowerShell),
+        CompletionShell::Zsh => generate_shell(clap_complete::Shell::Zsh),
+        CompletionShell::Nushell => generate_shell(clap_complete_nushell::Nushell),
+    }
+}
+
 #[derive(Subcommand, Debug)]
 enum Commands {
     /// Create a pre-populated GitHub issue with information about your configuration
@@ -188,7 +216,7 @@ fn main() {
                 (_, _, true) => Target::Continuation,
                 (_, _, _) => Target::Main,
             };
-            print::prompt(properties, target)
+            print::prompt(properties, target);
         }
         Commands::Module {
             name,
@@ -211,7 +239,7 @@ fn main() {
             let context = Context::default();
             if let Some(name) = name {
                 if let Some(value) = value {
-                    configure::update_configuration(&context, &name, &value)
+                    configure::update_configuration(&context, &name, &value);
                 }
             } else if let Err(reason) = configure::edit_configuration(&context, None) {
                 eprintln!("Could not edit configuration: {reason}");
@@ -222,7 +250,7 @@ fn main() {
             configure::print_configuration(&Context::default(), default, &name);
         }
         Commands::Toggle { name, value } => {
-            configure::toggle_configuration(&Context::default(), &name, &value)
+            configure::toggle_configuration(&Context::default(), &name, &value);
         }
         Commands::BugReport => bug_report::create(),
         Commands::Time => {
@@ -236,16 +264,11 @@ fn main() {
         }
         Commands::Explain(props) => print::explain(props),
         Commands::Timings(props) => print::timings(props),
-        Commands::Completions { shell } => generate(
-            shell,
-            &mut Cli::command(),
-            "starship",
-            &mut io::stdout().lock(),
-        ),
+        Commands::Completions { shell } => generate_completions(shell),
         Commands::Session => println!(
             "{}",
-            rand::thread_rng()
-                .sample_iter(&Alphanumeric)
+            rand::rng()
+                .sample_iter(rand::distr::Alphanumeric)
                 .take(16)
                 .map(char::from)
                 .collect::<String>()
@@ -257,16 +280,8 @@ fn main() {
 
 /// Initialize global `rayon` thread pool
 fn init_global_threadpool() {
-    // Allow overriding the number of threads
-    let num_threads = std::env::var("STARSHIP_NUM_THREADS")
-        .ok()
-        .and_then(|s| s.parse().ok())
-        // Default to the number of logical cores,
-        // but restrict the number of threads to 8
-        .unwrap_or_else(|| available_parallelism().map(usize::from).unwrap_or(1).min(8));
-
     rayon::ThreadPoolBuilder::new()
-        .num_threads(num_threads)
+        .num_threads(num_rayon_threads())
         .build_global()
         .expect("Failed to initialize worker thread pool");
 }
