@@ -20,6 +20,7 @@ pub const ALL_MODULES: &[&str] = &[
     "cobol",
     "conda",
     "container",
+    "cpp",
     "crystal",
     "daml",
     "dart",
@@ -60,7 +61,10 @@ pub const ALL_MODULES: &[&str] = &[
     "lua",
     "memory_usage",
     "meson",
+    "mise",
+    "mojo",
     "nats",
+    "netns",
     "nim",
     "nix_shell",
     "nodejs",
@@ -73,6 +77,7 @@ pub const ALL_MODULES: &[&str] = &[
     "perl",
     "php",
     "pijul_channel",
+    "pixi",
     "pulumi",
     "purescript",
     "python",
@@ -176,7 +181,7 @@ impl<'a> Module<'a> {
     }
 }
 
-impl<'a> fmt::Display for Module<'a> {
+impl fmt::Display for Module<'_> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let ansi_strings = self.ansi_strings();
         write!(f, "{}", AnsiStrings(&ansi_strings))
