@@ -4,7 +4,7 @@ use std::str::FromStr;
 
 use chrono::DateTime;
 use ini::Ini;
-use once_cell::unsync::OnceCell;
+use std::cell::OnceCell;
 
 use super::{Context, Module, ModuleConfig};
 
@@ -305,7 +305,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
 mod tests {
     use crate::test::ModuleRenderer;
     use nu_ansi_term::Color;
-    use std::fs::{create_dir, File};
+    use std::fs::{File, create_dir};
     use std::io::{self, Write};
 
     #[test]
@@ -497,13 +497,15 @@ mod tests {
         let config_path = dir.path().join("credentials");
         create_dir(&config_path)?;
 
-        assert!(ModuleRenderer::new("aws")
-            .env(
-                "AWS_SHARED_CREDENTIALS_FILE",
-                config_path.to_string_lossy().as_ref(),
-            )
-            .collect()
-            .is_none());
+        assert!(
+            ModuleRenderer::new("aws")
+                .env(
+                    "AWS_SHARED_CREDENTIALS_FILE",
+                    config_path.to_string_lossy().as_ref(),
+                )
+                .collect()
+                .is_none()
+        );
 
         dir.close()
     }
@@ -514,10 +516,12 @@ mod tests {
         let config_path = dir.path().join("config");
         create_dir(&config_path)?;
 
-        assert!(ModuleRenderer::new("aws")
-            .env("AWS_CONFIG_FILE", config_path.to_string_lossy().as_ref())
-            .collect()
-            .is_none());
+        assert!(
+            ModuleRenderer::new("aws")
+                .env("AWS_CONFIG_FILE", config_path.to_string_lossy().as_ref())
+                .collect()
+                .is_none()
+        );
 
         dir.close()
     }
@@ -702,7 +706,7 @@ credential_process = /opt/bin/awscreds-retriever
                 .collect();
 
             let possible_values = [
-                "30m2s", "30m1s", "30m", "29m59s", "29m58s", "29m57s", "29m56s", "29m55s",
+                "30m2s", "30m1s", "30m0s", "29m59s", "29m58s", "29m57s", "29m56s", "29m55s",
             ];
             let possible_values = possible_values.map(|duration| {
                 let segment_colored = format!("☁️  astronauts (ap-northeast-2) [{duration}] ");
@@ -756,7 +760,7 @@ aws_secret_access_key=dummy
                 // In principle, "30m" should be correct. However, bad luck in scheduling
                 // on shared runners may delay it.
                 let possible_values = [
-                    "30m2s", "30m1s", "30m", "29m59s", "29m58s", "29m57s", "29m56s", "29m55s",
+                    "30m2s", "30m1s", "30m0s", "29m59s", "29m58s", "29m57s", "29m56s", "29m55s",
                 ];
                 let possible_values = possible_values.map(|duration| {
                     let segment_colored = format!("☁️  astronauts (ap-northeast-2) [{duration}] ");
