@@ -20,6 +20,9 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     if config.ignore_base && conda_env == "base" {
         return None;
     }
+    if !context.detect_env_vars(&config.detect_env_vars) {
+        return None;
+    }
 
     let conda_env = truncate(&conda_env, config.truncation_length).unwrap_or(conda_env);
 
@@ -54,7 +57,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
 #[cfg(test)]
 mod tests {
     use crate::test::ModuleRenderer;
-    use ansi_term::Color;
+    use nu_ansi_term::Color;
 
     #[test]
     fn not_in_env() {
@@ -80,6 +83,18 @@ mod tests {
         assert_eq!(expected, actual);
     }
 
+    #[test]
+    fn ignore_pixi_envs() {
+        let actual = ModuleRenderer::new("conda")
+            .env("CONDA_DEFAULT_ENV", "my-env")
+            .env("PIXI_ENVIRONMENT_NAME", "my-env")
+            .collect();
+
+        let expected = None;
+
+        assert_eq!(expected, actual);
+    }
+
     #[test]
     fn env_set() {
         let actual = ModuleRenderer::new("conda")
