@@ -34,6 +34,10 @@ pub fn module<'a>(name: &str, context: &'a Context) -> Option<Module<'a>> {
         }
     }
 
+    if config.require_repo && context.get_repo().is_err() {
+        return None;
+    }
+
     // Note: Forward config if `Module` ends up needing `config`
     let mut module = Module::new(&format!("custom.{name}"), config.description, None);
 
@@ -55,8 +59,22 @@ pub fn module<'a>(name: &str, context: &'a Context) -> Option<Module<'a>> {
         }
     }
 
-    let parsed = StringFormatter::new(config.format).and_then(|formatter| {
-        formatter
+    let variables_closure = |variable: &str| match variable {
+        "output" => {
+            let output = exec_command(config.command, context, &config)?;
+            let trimmed = output.trim();
+
+            if trimmed.is_empty() {
+                None
+            } else {
+                Some(Ok(trimmed.to_string()))
+            }
+        }
+        _ => None,
+    };
+
+    let parsed = StringFormatter::new(config.format).and_then(|mut formatter| {
+        formatter = formatter
             .map_meta(|var, _| match var {
                 "symbol" => Some(config.symbol),
                 _ => None,
@@ -64,21 +82,15 @@ pub fn module<'a>(name: &str, context: &'a Context) -> Option<Module<'a>> {
             .map_style(|variable| match variable {
                 "style" => Some(Ok(config.style)),
                 _ => None,
-            })
-            .map_no_escaping(|variable| match variable {
-                "output" => {
-                    let output = exec_command(config.command, context, &config)?;
-                    let trimmed = output.trim();
+            });
 
-                    if trimmed.is_empty() {
-                        None
-                    } else {
-                        Some(Ok(trimmed.to_string()))
-                    }
-                }
-                _ => None,
-            })
-            .parse(None, Some(context))
+        if config.unsafe_no_escape {
+            formatter = formatter.map_no_escaping(variables_closure)
+        } else {
+            formatter = formatter.map(variables_closure)
+        }
+
+        formatter.parse(None, Some(context))
     });
 
     match parsed {
@@ -106,8 +118,8 @@ fn get_config<'a>(module_name: &str, context: &'a Context<'a>) -> Option<&'a tom
         return config;
     } else if let Some(modules) = context.config.get_custom_modules() {
         log::debug!(
-                "top level format contains custom module {module_name:?}, but no configuration was provided. Configuration for the following modules were provided: {:?}",
-                DebugCustomModules(modules),
+            "top level format contains custom module {module_name:?}, but no configuration was provided. Configuration for the following modules were provided: {:?}",
+            DebugCustomModules(modules),
         );
     } else {
         log::debug!(
@@ -204,7 +216,9 @@ fn shell_command(cmd: &str, config: &CustomConfig, context: &Context) -> Option<
     match output.wait().ok()? {
         None => {
             log::warn!("Executing custom command {cmd:?} timed out.");
-            log::warn!("You can set command_timeout in your config to a higher value or set ignore_timeout to true for this module to allow longer-running commands to keep executing.");
+            log::warn!(
+                "You can set command_timeout in your config to a higher value or set ignore_timeout to true for this module to allow longer-running commands to keep executing."
+            );
             None
         }
         Some(status) => Some(status),
@@ -240,6 +254,11 @@ fn exec_when(cmd: &str, config: &CustomConfig, context: &Context) -> bool {
 fn exec_command(cmd: &str, context: &Context, config: &CustomConfig) -> Option<String> {
     log::trace!("Running '{cmd}'");
 
+    #[cfg(test)]
+    if cmd == "__starship_to_be_escaped" {
+        return Some("`to_be_escaped`".to_string());
+    }
+
     if let Some(output) = shell_command(cmd, config, context) {
         if !output.status.success() {
             log::trace!("Non-zero exit code '{:?}'", output.status.code());
@@ -294,7 +313,8 @@ fn handle_shell(command: &mut Command, shell: &str, shell_args: &[&str]) -> bool
 mod tests {
     use super::*;
 
-    use crate::test::ModuleRenderer;
+    use crate::context::Shell;
+    use crate::test::{FixtureProvider, ModuleRenderer, fixture_repo};
     use nu_ansi_term::Color;
     use std::fs::File;
     use std::io;
@@ -721,4 +741,83 @@ mod tests {
         let expected = None;
         assert_eq!(expected, actual);
     }
+
+    #[test]
+    fn test_render_require_repo_not_in() -> io::Result<()> {
+        let repo_dir = tempfile::tempdir()?;
+
+        let actual = ModuleRenderer::new("custom.test")
+            .path(repo_dir.path())
+            .config(toml::toml! {
+                [custom.test]
+                when = true
+                require_repo = true
+                format = "test"
+            })
+            .collect();
+        let expected = None;
+        assert_eq!(expected, actual);
+        repo_dir.close()
+    }
+
+    #[test]
+    fn test_render_require_repo_in() -> io::Result<()> {
+        let repo_dir = fixture_repo(FixtureProvider::Git)?;
+
+        let actual = ModuleRenderer::new("custom.test")
+            .path(repo_dir.path())
+            .config(toml::toml! {
+                [custom.test]
+                when = true
+                require_repo = true
+                format = "test"
+            })
+            .collect();
+        let expected = Some("test".to_string());
+        assert_eq!(expected, actual);
+        repo_dir.close()
+    }
+
+    #[test]
+    fn output_is_escaped() -> io::Result<()> {
+        let dir = tempfile::tempdir()?;
+
+        let actual = ModuleRenderer::new("custom.test")
+            .path(dir.path())
+            .config(toml::toml! {
+                [custom.test]
+                format = "$output"
+                command = "__starship_to_be_escaped"
+                when = true
+                ignore_timeout = true
+            })
+            .shell(Shell::Bash)
+            .collect();
+        let expected = Some("\\`to_be_escaped\\`".to_string());
+        assert_eq!(expected, actual);
+
+        dir.close()
+    }
+
+    #[test]
+    fn unsafe_no_escape() -> io::Result<()> {
+        let dir = tempfile::tempdir()?;
+
+        let actual = ModuleRenderer::new("custom.test")
+            .path(dir.path())
+            .config(toml::toml! {
+                [custom.test]
+                format = "$output"
+                command = "__starship_to_be_escaped"
+                when = true
+                ignore_timeout = true
+                unsafe_no_escape = true
+            })
+            .shell(Shell::Bash)
+            .collect();
+        let expected = Some("`to_be_escaped`".to_string());
+        assert_eq!(expected, actual);
+
+        dir.close()
+    }
 }
