@@ -1,4 +1,4 @@
-use std::io::{Error, ErrorKind};
+use std::io::Error;
 use std::path::Path;
 
 use super::utils::truncate::truncate_text;
@@ -6,7 +6,6 @@ use super::{Context, Module, ModuleConfig};
 
 use crate::configs::hg_branch::HgBranchConfig;
 use crate::formatter::StringFormatter;
-use crate::modules::utils::path::PathExt;
 use crate::utils::read_file;
 
 /// Creates a module with the Hg bookmark or branch in the current directory
@@ -27,18 +26,18 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
             "\"truncation_length\" should be a positive value, found {}",
             config.truncation_length
         );
-        std::usize::MAX
+        usize::MAX
     } else {
         config.truncation_length as usize
     };
 
-    let repo_root = get_hg_repo_root(context).ok()?;
-    let branch_name = get_hg_current_bookmark(repo_root).unwrap_or_else(|_| {
-        get_hg_branch_name(repo_root).unwrap_or_else(|_| String::from("default"))
+    let repo_root = context.begin_ancestor_scan().set_folders(&[".hg"]).scan()?;
+    let branch_name = get_hg_current_bookmark(&repo_root).unwrap_or_else(|_| {
+        get_hg_branch_name(&repo_root).unwrap_or_else(|_| String::from("default"))
     });
 
     let branch_graphemes = truncate_text(&branch_name, len, config.truncation_symbol);
-    let topic_graphemes = if let Ok(topic) = get_hg_topic_name(repo_root) {
+    let topic_graphemes = if let Ok(topic) = get_hg_topic_name(&repo_root) {
         truncate_text(&topic, len, config.truncation_symbol)
     } else {
         String::new()
@@ -73,20 +72,6 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     Some(module)
 }
 
-fn get_hg_repo_root<'a>(ctx: &'a Context) -> Result<&'a Path, Error> {
-    let dir = ctx.current_dir.as_path();
-    let dev_id = dir.device_id();
-    for root_dir in dir.ancestors() {
-        if dev_id != root_dir.device_id() {
-            break;
-        }
-        if root_dir.join(".hg").is_dir() {
-            return Ok(root_dir);
-        }
-    }
-    Err(Error::new(ErrorKind::Other, "No .hg found!"))
-}
-
 fn get_hg_branch_name(hg_root: &Path) -> Result<String, Error> {
     match read_file(hg_root.join(".hg").join("branch")) {
         Ok(b) => Ok(b.trim().to_string()),
@@ -109,7 +94,7 @@ mod tests {
     use std::io;
     use std::path::Path;
 
-    use crate::test::{fixture_repo, FixtureProvider, ModuleRenderer};
+    use crate::test::{FixtureProvider, ModuleRenderer, fixture_repo};
     use crate::utils::create_command;
 
     enum Expect<'a> {
