@@ -1,7 +1,7 @@
 use crate::module::ALL_MODULES;
 use serde::de::{
-    value::{Error as ValueError, MapDeserializer, SeqDeserializer},
     Deserializer, Error, IntoDeserializer, Visitor,
+    value::{Error as ValueError, MapDeserializer, SeqDeserializer},
 };
 use std::{cmp::Ordering, fmt};
 use toml::Value;
@@ -103,9 +103,9 @@ impl ValueDeserializer<'_> {
 }
 
 impl<'de> IntoDeserializer<'de> for ValueDeserializer<'de> {
-    type Deserializer = ValueDeserializer<'de>;
+    type Deserializer = Self;
 
-    fn into_deserializer(self) -> ValueDeserializer<'de> {
+    fn into_deserializer(self) -> Self {
         self
     }
 }
@@ -176,9 +176,7 @@ impl<'de> Deserializer<'de> for ValueDeserializer<'de> {
             .info
             .filter(|StructInfo { name, .. }| name == &"StarshipRootConfig")
             .and(self.current_key)
-            .map_or(false, |key| {
-                ALL_MODULES.contains(&key) || key == "custom" || key == "env_var"
-            })
+            .is_some_and(|key| ALL_MODULES.contains(&key) || key == "custom" || key == "env_var")
         {
             return visitor.visit_none();
         }
