@@ -2,21 +2,21 @@ use crate::context::{Context, Shell, Target};
 use crate::logger::StarshipLogger;
 use crate::{
     config::StarshipConfig,
-    utils::{create_command, CommandOutput},
+    utils::{CommandOutput, create_command},
 };
 use log::{Level, LevelFilter};
-use once_cell::sync::Lazy;
 use std::fs;
 use std::io;
 use std::path::{Path, PathBuf};
+use std::sync::LazyLock;
 use std::sync::Once;
 use tempfile::TempDir;
 
-static FIXTURE_DIR: Lazy<PathBuf> =
-    Lazy::new(|| PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("src/test/fixtures/"));
+static FIXTURE_DIR: LazyLock<PathBuf> =
+    LazyLock::new(|| PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("src/test/fixtures/"));
 
-static GIT_FIXTURE: Lazy<PathBuf> = Lazy::new(|| FIXTURE_DIR.join("git-repo.bundle"));
-static HG_FIXTURE: Lazy<PathBuf> = Lazy::new(|| FIXTURE_DIR.join("hg-repo.bundle"));
+static GIT_FIXTURE: LazyLock<PathBuf> = LazyLock::new(|| FIXTURE_DIR.join("git-repo.bundle"));
+static HG_FIXTURE: LazyLock<PathBuf> = LazyLock::new(|| FIXTURE_DIR.join("hg-repo.bundle"));
 
 static LOGGER: Once = Once::new();
 
@@ -246,12 +246,13 @@ pub fn fixture_repo(provider: FixtureProvider) -> io::Result<TempDir> {
         }
         FixtureProvider::GitBare => {
             let path = tempfile::tempdir()?;
-            gix::ThreadSafeRepository::init(
-                &path,
-                gix::create::Kind::Bare,
-                gix::create::Options::default(),
-            )
-            .map_err(|err| io::Error::new(io::ErrorKind::Other, err))?;
+
+            create_command("git")?
+                .current_dir(path.path())
+                .args(["clone", "-b", "master", "--bare"])
+                .arg(GIT_FIXTURE.as_os_str())
+                .arg(path.path())
+                .output()?;
             Ok(path)
         }
         FixtureProvider::Hg => {
